<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ns="http://www.bourse.lu/rap/O42"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:fnbcl="http://www.bcl.lu/2006/bcl-xpath-functions"
	xmlns:ext="java:lu.bourse.api.deposant.action.xsl.XslManager"
	xmlns:saxon="http://saxon.sf.net/"
	extension-element-prefixes="saxon"
	version="2.0">
	
	<xsl:import href="../EDIFACT/EDIFACT.xsl"/>

	<xsl:param name="formatDateCd" />
	<xsl:output method="text" />
	
	<!-- 
		Nombre de segments fixes dans le message EDIFACT
		(entre les segments UNH et UNT inclus).
	-->
	<xsl:variable name="compteurSegments" select="$NB_SEGMENTS_FIXES"/>
	
	<xsl:variable name="compteurCPT" select="0" as="xs:integer" saxon:assignable="yes"/>
	
	<xsl:template match="/ns:MsgInO42">
		<xsl:call-template name="HEADER-SECTION"/>
 		<xsl:call-template name="SEGMENT-GROUP-1"/>
		 <xsl:call-template name="SEGMENT-GROUP-3"/>
		<xsl:call-template name="SEGMENT-GROUP-4"/>
		<xsl:call-template name="SUMMARY-SECTION">
			<xsl:with-param name="compteur" select="$compteurCPT"/>
		</xsl:call-template>
		<xsl:call-template name="SEGMENT-GROUP-5"/>
	</xsl:template>
	
	<xsl:template name="HEADER-SECTION">
		<xsl:variable name="root" select="ns:other/ns:EltTech"/>
		<xsl:variable name="idAc" select="$root/ns:CdIdentAcCssf"/>
		<xsl:variable name="idAc7digit" select="ext:convertIdAcTo7Digit($idAc)"/>			
		<xsl:call-template name="EDIFACT-UNA"/>
		<xsl:call-template name="EDIFACT-UNB">
			<xsl:with-param name="cdIdentAc" select="$idAc7digit" />
			<xsl:with-param name="dtCre" select="$root/ns:DtCre" as="xs:dateTime" />
			<xsl:with-param name="motPasAc" select="$root/ns:MotPasAc" />
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-UNH">
			<xsl:with-param name="cdIdentAc" select="$idAc7digit" />
			<xsl:with-param name="dtCre" select="$root/ns:DtCre" as="xs:dateTime"/>
			<xsl:with-param name="numMess" select="$root/ns:NumMess" />
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-BGM">
			<xsl:with-param name="typeRapport" select="'TABLE-O-4.2--D-L-00001'"/>
		</xsl:call-template>
		<xsl:comment>Preparation Date...</xsl:comment>
		<xsl:call-template name="EDIFACT-DTM">
			<xsl:with-param name="typeDate" select="'242'" />
			<xsl:with-param name="date" select="$root/ns:DtCre" as="xs:dateTime"/>
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:comment>...Preparation Date</xsl:comment>
		<xsl:comment>Transmission Date...</xsl:comment>
		<xsl:call-template name="EDIFACT-DTM">
			<xsl:with-param name="typeDate" select="'243'" />
			<xsl:with-param name="date" select="$root/ns:DtEnvoi" as="xs:dateTime"/>
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:comment>...Transmission Date</xsl:comment>
		 <xsl:variable name="root" select="ns:SeqInO42/ns:Conc1/ns:Context/ns:CollCompartRapO42"/>
		<xsl:call-template name="EDIFACT-PEI">
			<xsl:with-param name="periode" select="'Y'"/>
			<xsl:with-param name="dtDebRap" select="$root/ns:DtDebRap" as="xs:date"/>
			<xsl:with-param name="dtFinRap" select="$root/ns:DtFinRap" as="xs:date"/>
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:variable name="root" select="ns:SeqInO42/ns:Conc1/ns:Context/ns:StructJurOpc"/>
		<xsl:variable name="cdStructJurOpcTemp" select="$root/ns:CdStructJurOpc"/>
		<xsl:call-template name="EDIFACT-SJS">
<!--<xsl:with-param name="cdStructJurOpc" select="ext:mapping('CD_STRUCT_JUR_OPC_BDL', $cdStructJurOpcTemp)"/>-->
			<xsl:with-param name="cdStructJurOpc" select="ext:mappingCdStructJurOpcBdlToCdStructJurOpcEdifact($cdStructJurOpcTemp)"/>
			<xsl:with-param name="codifInstrFonds" select="$root/../ns:CollCompartRapO42/ns:CdCssfOpc"/>
			<xsl:with-param name="codifInstrCompart" select="$root/../ns:CollCompartRapO42/ns:CdCssfCompart"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SEGMENT-GROUP-1">
		<xsl:variable name="root" select="ns:SeqInO42/ns:Conc1/ns:Context/ns:InstrFonds"/>
		<xsl:call-template name="EDIFACT-NAD">
			<xsl:with-param name="libAbrInstr" select="$root/ns:LibAbrInstr"/>
			<xsl:with-param name="adr" select="$root/../ns:Tech/ns:Adr"/>
			<xsl:with-param name="ville" select="$root/../ns:Tech/ns:Ville"/>
			<xsl:with-param name="cdPostal" select="$root/../ns:Tech/ns:CdPostal"/>
<!-- <xsl:with-param name="pays" select="ext:mapping('IDENTIFIANT_PAYS', $root/../ns:Tech/ns:Pays)"/>-->
			<xsl:with-param name="pays" select="ext:mappingIdPaysToCdPaysIso($root/../ns:Tech/ns:Pays)"/>
		</xsl:call-template>
		<xsl:variable name="root" select="ns:SeqInO42/ns:Conc1/ns:Context/ns:TechContact"/>
		<xsl:call-template name="EDIFACT-CTA">
			<xsl:with-param name="titre" select="$root/ns:Titre"/>
			<xsl:with-param name="prenom" select="$root/ns:Prenom"/>
			<xsl:with-param name="nom" select="$root/ns:Nom"/>
		</xsl:call-template>
		  <xsl:call-template name="EDIFACT-COM">
			<xsl:with-param name="tel" select="$root/ns:Tel"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SEGMENT-GROUP-3">
		<xsl:variable name="root" select="ns:SeqInO42/ns:Conc1/ns:Context/ns:Dev"/>
		<xsl:call-template name="EDIFACT-CUX">
			<xsl:with-param name="cdDevIso" select="$root/ns:CdDevIso"/>
			<xsl:with-param name="txChgeIml" select="$root/../ns:CollCompartRapO42/ns:TxChge"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-UNS">
			<xsl:with-param name="type" select="'D'"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SEGMENT-GROUP-4">
		<xsl:variable name="champ" select="ns:SeqInO42/ns:Conc1/ns:P100/ns:L101/ns:Mt" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="'-101'"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO42/ns:Conc1/ns:P100/ns:L102/ns:Mt" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="'-102'"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO42/ns:Conc1/ns:P100/ns:L103/ns:Mt" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="'-103'"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO42/ns:Conc1/ns:P200/ns:L201/ns:Mt" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="'-201'"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
		<xsl:variable name="champ" select="ns:SeqInO42/ns:Conc1/ns:P200/ns:L202/ns:Mt" />
		<xsl:call-template name="LIGNE-REPORTING">
			<xsl:with-param name="coded-account" select="'-202'"/>
			<xsl:with-param name="montant" select="$champ"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SEGMENT-GROUP-5">
		<xsl:param name="nbSegments"/>
		<xsl:variable name="root" select="ns:other/ns:EltTech"/>
		<xsl:variable name="idAc" select="$root/ns:CdIdentAcCssf"/>
		<xsl:variable name="idAc7digit" select="ext:convertIdAcTo7Digit($idAc)"/>
    <xsl:call-template name="EDIFACT-FTX" />
		<xsl:call-template name="EDIFACT-AUT">
			<xsl:with-param name="cdAuthent" select="$root/ns:CdAuthent"/>
		</xsl:call-template>
		<xsl:variable name="root" select="/ns:MsgInO42/ns:other/ns:EltTech"/>
		<xsl:call-template name="EDIFACT-DTM">
			<xsl:with-param name="typeDate" select="'218'"/>
			<xsl:with-param name="date" select="$root/ns:DtValidat" as="xs:dateTime"/>
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		<xsl:variable name="root" select="ns:other/ns:EltTech"/>
 		<xsl:call-template name="EDIFACT-UNT">
 		<!-- 			$compteurSegments+1 car ajout du segment FTX -->
			<xsl:with-param name="nbSegments" select="$compteurCPT*3+$compteurSegments+1"/>
			<xsl:with-param name="cdIdentAc" select="$idAc7digit" />
			<xsl:with-param name="dtCre" select="$root/ns:DtCre" as="xs:dateTime" />
			<xsl:with-param name="numMess" select="$root/ns:NumMess" />
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>
		
		<xsl:variable name="root" select="ns:other/ns:EltTech"/>
		<xsl:variable name="idAc" select="$root/ns:CdIdentAcCssf"/>
		<xsl:variable name="idAc7digit" select="ext:convertIdAcTo7Digit($idAc)"/>			
		<xsl:call-template name="EDIFACT-UNZ">
			<xsl:with-param name="cdIdentAc" select="$idAc7digit" />
			<xsl:with-param name="dtCre" select="$root/ns:DtCre" as="xs:dateTime" />
			<xsl:with-param name="formatDateCd" select="$formatDateCd" />
		</xsl:call-template>

	</xsl:template>
	
	<xsl:template name="LIGNE-REPORTING">
		<xsl:param name="coded-account"/>
		<xsl:param name="montant" as="xs:decimal"/>
		<saxon:assign name="compteurCPT" select="$compteurCPT+1"/>
		<xsl:call-template name="EDIFACT-CPT">
			<xsl:with-param name="coded-account" select="$coded-account"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-VAL">
			<xsl:with-param name="type" select="'AMT'"/>
			<xsl:with-param name="montant" select="$montant" as="xs:decimal"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-QTY">
			<xsl:with-param name="compteur" select="1"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="SUMMARY-SECTION">
		<xsl:param name="compteur"/>
		<xsl:call-template name="EDIFACT-UNS">
			<xsl:with-param name="type" select="'S'"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-QTY">
			<xsl:with-param name="compteur" select="$compteur"/>
		</xsl:call-template>
		<xsl:call-template name="EDIFACT-VAL">
			<xsl:with-param name="type" select="'AMT'"/>
			<xsl:with-param name="montant" select="0" as="xs:decimal"/>
		</xsl:call-template>
	</xsl:template>
	
</xsl:stylesheet>
